@@ -145,7 +145,7 @@ class FederatedPipelineBase(AMLPipelineHelper):
     @experimental(message=EXPERIMENTAL_WARNING_MSG)
     def postprocess(self, config: DictConfig, **kwargs) -> StepOutput:
         """
-        Optional user-defined postprocess step which reads outputs from the final `midprocess` step and writes to the `noncompliant_datastore`.
+        Optional user-defined postprocess step which reads outputs from the final `midprocess` step and writes to the `compliant_datastore`.
 
         Returns:
             a component/subgraph instance, and a list of output dataset names.
@@ -157,7 +157,7 @@ class FederatedPipelineBase(AMLPipelineHelper):
         self, config: DictConfig, silo: DictConfig, input: Output = None, **kwargs
     ) -> StepOutput:
         """
-        User-defined train step happening at each silo. This reads outputs from `preprocess` or `midprocess`, and sends outputs back to the `noncompliant_datastore`.
+        User-defined train step happening at each silo. This reads outputs from `preprocess` or `midprocess`, and sends outputs back to the `compliant_datastore`.
 
         Returns:
             a component/subgraph instance, and a list of output dataset names to be passed to the downstream pipeline.
@@ -250,6 +250,15 @@ class FederatedPipelineBase(AMLPipelineHelper):
                 base_name=base_name,
             )
 
+    def _update_configs_in_silo(self, step, compute_target, datastore):
+        log.info(
+            f"Updating the compute target to {compute_target} and datastore to {datastore} for component {step.name}."
+        )
+        step.runsettings.configure(
+            target=compute_target,
+        )
+        self._set_all_outputs_to(step, output_mode=None, datastore_name=datastore)
+
     def _train_in_silo_once(
         self, silo_name: str, silo: DictConfig, cool_name: str, **prev_output
     ) -> dict:
@@ -264,19 +273,20 @@ class FederatedPipelineBase(AMLPipelineHelper):
         step = train_step.step
         if isinstance(step, Pipeline):
             train_output = step.outputs
+            step.node_name = self.create_silo_specific_name(silo_name)
             for node in step._expand_pipeline_nodes():
-                node._node_name = self.create_silo_specific_name(silo_name)
+                self._update_configs_in_silo(node, silo.compute, silo.datastore)
         elif isinstance(step, Component):
             train_output = dataset_name_to_reference(step, train_step.outputs)
             step._node_name = self.create_silo_specific_name(silo_name)
-
+            self._update_configs_in_silo(step, silo.compute, silo.datastore)
         else:
             raise Exception(
                 f"The output of train step must be a Pipeline object or a Component object. You are using {type(step)}"
             )
 
         silo_output = self._check_if_data_transfer_is_activated_and_process(
-            self.config.compute.noncompliant_datastore,
+            self.config.compute.compliant_datastore,
             cool_name + "/" + silo_name,
             **train_output,
         )
