@@ -324,7 +324,7 @@ class AMLModuleLoader:
             module_namespace = None
             is_in_manifest = False
             if not (self.use_remote_when_component_not_in_manifest):
-                raise LookupError(
+                log.warning(
                     f"Module key '{module_key}' could not be found in modules.manifest configuration or in required_modules() method. If you want to try and load it from the workspace, set 'module_loader.use_remote_when_component_not_in_manifest' to True in the config."
                 )
 
