@@ -56,6 +56,7 @@ from shrike.pipeline.telemetry_utils import TelemetryLogger
 from shrike._core import is_eyesoff_helper
 
 from functools import wraps
+from functools import lru_cache
 
 
 log = logging.getLogger(__name__)
@@ -1034,6 +1035,31 @@ class AMLPipelineHelper:
                 f"During build() of graph class {self.__class__.__name__}, call to self.apply_recommended_runsettings() is wrong: key used as first argument ('{module_key}') maps to a module reference {module_manifest_entry} which name is different from the module instance provided as 2nd argument (name={module_instance.name}), did you use the wrong module key as first argument?"
             )
 
+    @lru_cache(maxsize=128)
+    def _get_component_name_from_instance(self, component_instance):
+        """We need to have this _get_component_name_from_instance() to get component name for apply_smart_runsettings(),
+        and can't simply use "component_name = component_instance.name". Otherwise apply_smart_runsettings() might work incorrectly for local
+        components. See more detailed explanation and examples here: https://github.com/Azure/shrike/issues/411"""
+        component_manifest_list = self.config.modules.manifest
+        component_name = component_instance.name
+        for component_manifest_entry in component_manifest_list:
+            try:
+                if component_manifest_entry["name"] == component_name:
+                    return component_manifest_entry["key"] or component_name
+                if "namespace" in component_manifest_entry:
+                    component_entry_name = (
+                        component_manifest_entry["namespace"]
+                        + "://"
+                        + component_manifest_entry["name"]
+                    )
+                    if component_entry_name == component_name:
+                        return component_manifest_entry["key"] or component_name
+            except ValueError:
+                pass
+        raise ValueError(
+            f"Could not find component matching {component_name}. Please check your spelling."
+        )
+
     def apply_smart_runsettings(
         self,
         component_instance,
@@ -1061,8 +1087,10 @@ class AMLPipelineHelper:
             sweep (bool): is the component using sweep?
             custom_runtime_arguments (dict): any additional custom args
         """
+        # infer component_name
+        component_name = self._get_component_name_from_instance(component_instance)
         self.apply_recommended_runsettings(
-            component_instance.name,
+            component_name,
             component_instance,
             gpu,
             hdi,
